@@ -268,7 +268,7 @@ namespace Dune
     {
       // apply space filling curve orderung to the inserted elements
       // see common/hsfc.hh for details
-      typename ALUGrid::CollectiveCommunication comm( communicator_ );
+      typename ALUGrid::Communication comm( communicator_ );
 
       // if we are in parallel insertion mode we need communication
       const bool foundGlobalIndex = comm.max( foundGlobalIndex_ );
@@ -822,7 +822,7 @@ namespace Dune
           typedef typename ALU3DSPACE Gitter::hbndseg::bnd_t bnd_t ;
           bnd_t bndId[ 2 ] = { bnd_t( facePair.first.second ),
                                bnd_t( facePair.second.second ) };
-          mgb.InsertUniquePeriodic4( perel, bndId );
+          mgb.InsertUniquePeriodic( perel, bndId );
 
         }
         else if( elementType == tetra )
@@ -836,7 +836,7 @@ namespace Dune
           typedef typename ALU3DSPACE Gitter::hbndseg::bnd_t bnd_t ;
           bnd_t bndId[ 2 ] = { bnd_t( facePair.first.second ),
                                bnd_t( facePair.second.second ) };
-          mgb.InsertUniquePeriodic3( perel, bndId );
+          mgb.InsertUniquePeriodic( perel, bndId );
         }
         else
           DUNE_THROW( GridError, "Invalid element type" );
@@ -1304,7 +1304,7 @@ namespace Dune
 
     // communicate unidentified boundaries and find process borders)
     // use the Grids communicator (ALUGridNoComm or ALUGridMPIComm)
-    typename ALUGrid::CollectiveCommunication comm( communicator_ );
+    typename ALUGrid::Communication comm( communicator_ );
 
     int numBoundariesMine = faceMap.size();
     std::vector< int > boundariesMine( numFaceCorners * numBoundariesMine );
