@@ -1657,10 +1657,9 @@ namespace ALUGrid
           in >> i;
           _ldbMethod = (LoadBalancer::DataBase::method) i;
         }
-        else
+        else if (ALUGridExternalParameters::verbosityLevel() > 1)
         {
-          std::cerr << "WARNING (ignored): Could not open file 'alugrid.cfg', using default values ";
-          std::cerr << _ldbUnder << " < [balance] < " << _ldbOver << ", partitioning method '" << LoadBalancer::DataBase::methodToString( _ldbMethod ) << "'." << std::endl;
+          std::cerr << "WARNING (ignored): Could not open file 'alugrid.cfg', using default values!" << std::endl;
         }
       } // got values on rank 0
 
@@ -1678,6 +1677,11 @@ namespace ALUGrid
       _ldbMethod = (LoadBalancer::DataBase::method ) buff[ 2 ];
     }
 
+    if( mpa.myrank() == 0 && ALUGridExternalParameters::verbosityLevel() > 1)
+    {
+      std::cerr << "ALUGrid-LB values: " << _ldbUnder << " < [balance] < " << _ldbOver << ", partitioning method '" << LoadBalancer::DataBase::methodToString( _ldbMethod ) << "'." << std::endl;
+    }
+
     // we possibly need to initialize zoltan at some point - we will do it here...
     LoadBalancer::DataBase::initializeZoltan( _ldbMethod );
 
